OperationOutcome

Struct OperationOutcome 

pub struct OperationOutcome;
http://hl7.org/fhir/ValueSet/operation-outcome

Implementations

Source

impl OperationOutcome

pub fn delet_e_multipl_e_matches() -> BoundCode<Self>

Error: Multiple matches exist for the conditional delete

pub fn ms_g_aut_h_required() -> BoundCode<Self>

You must authenticate before you can use this service

pub fn ms_g_ba_d_format() -> BoundCode<Self>

Bad Syntax: “%s” must be a %s’

pub fn ms_g_ba_d_syntax() -> BoundCode<Self>

Bad Syntax in %s

pub fn ms_g_can_t_pars_e_content() -> BoundCode<Self>

Unable to parse feed (entry content type = “%s”)

pub fn ms_g_can_t_pars_e_root() -> BoundCode<Self>

Unable to parse feed (root element name = “%s”)

pub fn ms_g_created() -> BoundCode<Self>

New resource created

pub fn ms_g_dat_e_format() -> BoundCode<Self>

The Date value %s is not in the correct format (Xml Date Format required)

pub fn ms_g_deleted() -> BoundCode<Self>

This resource has been deleted

pub fn ms_g_delete_d_done() -> BoundCode<Self>

Resource deleted

pub fn ms_g_delete_d_id() -> BoundCode<Self>

The resource “%s” has been deleted

pub fn ms_g_duplicat_e_id() -> BoundCode<Self>

Duplicate Id %s for resource type %s

pub fn ms_g_erro_r_parsing() -> BoundCode<Self>

Error parsing resource Xml (%s)

pub fn ms_g_i_d_invalid() -> BoundCode<Self>

Id “%s” has an invalid character “%s”

pub fn ms_g_i_d_to_o_long() -> BoundCode<Self>

Id “%s” too long (length limit 36)

pub fn ms_g_invali_d_id() -> BoundCode<Self>

Id not accepted

pub fn ms_g_jso_n_object() -> BoundCode<Self>

Json Source for a resource should start with an object

pub fn ms_g_loca_l_fail() -> BoundCode<Self>

Unable to resolve local reference to resource %s

pub fn ms_g_n_o_exist() -> BoundCode<Self>

Resource Id “%s” does not exist

pub fn ms_g_n_o_match() -> BoundCode<Self>

No Resource found matching the query “%s”

pub fn ms_g_n_o_module() -> BoundCode<Self>

No module could be found to handle the request “%s”

pub fn ms_g_n_o_summary() -> BoundCode<Self>

No Summary for this resource

pub fn ms_g_o_p_no_t_allowed() -> BoundCode<Self>

Operation %s not allowed for resource %s (due to local configuration)

pub fn ms_g_para_m_chained() -> BoundCode<Self>

Unknown chained parameter name “%s”

pub fn ms_g_para_m_invalid() -> BoundCode<Self>

Parameter “%s” content is invalid

pub fn ms_g_para_m_modifie_r_invalid() -> BoundCode<Self>

Parameter “%s” modifier is invalid

pub fn ms_g_para_m_n_o_repeat() -> BoundCode<Self>

Parameter “%s” is not allowed to repeat

pub fn ms_g_para_m_unknown() -> BoundCode<Self>

Parameter “%s” not understood

pub fn ms_g_resourc_e_exampl_e_protected() -> BoundCode<Self>

Resources with identity “example” cannot be deleted (for testing/training purposes)

pub fn ms_g_resourc_e_i_d_fail() -> BoundCode<Self>

unable to allocate resource id

pub fn ms_g_resourc_e_i_d_mismatch() -> BoundCode<Self>

Resource Id Mismatch

pub fn ms_g_resourc_e_i_d_missing() -> BoundCode<Self>

Resource Id Missing

pub fn ms_g_resourc_e_no_t_allowed() -> BoundCode<Self>

Not allowed to submit a resource for this operation

pub fn ms_g_resourc_e_required() -> BoundCode<Self>

A resource is required

pub fn ms_g_resourc_e_typ_e_mismatch() -> BoundCode<Self>

Resource Type Mismatch

pub fn ms_g_sor_t_unknown() -> BoundCode<Self>

Unknown sort parameter name “%s”

pub fn ms_g_transactio_n_duplicat_e_id() -> BoundCode<Self>

Duplicate Identifier in transaction: %s

pub fn ms_g_transactio_n_missin_g_id() -> BoundCode<Self>

Missing Identifier in transaction - an entry.id must be provided

pub fn ms_g_unhandle_d_nod_e_type() -> BoundCode<Self>

Unhandled xml node type “%s”

pub fn ms_g_unknow_n_content() -> BoundCode<Self>

Unknown Content (%s) at %s

pub fn ms_g_unknow_n_operation() -> BoundCode<Self>

unknown FHIR http operation

pub fn ms_g_unknow_n_type() -> BoundCode<Self>

Resource Type “%s” not recognised

pub fn ms_g_updated() -> BoundCode<Self>

existing resource updated

pub fn ms_g_versio_n_aware() -> BoundCode<Self>

Version aware updates are required for this resource

pub fn ms_g_versio_n_awar_e_conflict() -> BoundCode<Self>

Update Conflict (server current version = “%s”, client version referenced = “%s”)

pub fn ms_g_versio_n_awar_e_url() -> BoundCode<Self>

Version specific URL not recognised

pub fn ms_g_wron_g_ns() -> BoundCode<Self>

This does not appear to be a FHIR element or resource (wrong namespace “%s”)

pub fn searc_h_multiple() -> BoundCode<Self>

Error: Multiple matches exist for %s search parameters “%s”

pub fn searc_h_none() -> BoundCode<Self>

Error: no processable search found for %s search parameters “%s”

pub fn updat_e_multipl_e_matches() -> BoundCode<Self>

Error: Multiple matches exist for the conditional update

pub fn null() -> BoundCode<Self>