pub struct RepositoryType;Expand description
http://hl7.org/fhir/ValueSet/repository-type
Implementations
Sourceimpl RepositoryType
impl RepositoryType
Sourcepub fn directlink() -> BoundCode<Self>
pub fn directlink() -> BoundCode<Self>
Click and see
Sourcepub fn oauth() -> BoundCode<Self>
pub fn oauth() -> BoundCode<Self>
Result need to be fetched with API and need LOGIN( or cookies are required when visiting the link of resource)
Sourcepub fn openapi() -> BoundCode<Self>
pub fn openapi() -> BoundCode<Self>
The URL is the RESTful or other kind of API that can access to the result.
Sourcepub fn other() -> BoundCode<Self>
pub fn other() -> BoundCode<Self>
Some other complicated or particular way to get resource from URL.
pub fn null() -> BoundCode<Self>