pub struct V3VaccineManufacturer;Expand description
http://terminology.hl7.org/ValueSet/v3-VaccineManufacturer
Implementations
Sourceimpl V3VaccineManufacturer
impl V3VaccineManufacturer
Sourcepub fn bay() -> BoundCode<Self>
pub fn bay() -> BoundCode<Self>
Bayer Corporation (includes Miles, Inc. and Cutter Laboratories)
Sourcepub fn bpc() -> BoundCode<Self>
pub fn bpc() -> BoundCode<Self>
Berna Products Corporation (includes Swiss Serum and Vaccine Institute Berne)
Sourcepub fn evn() -> BoundCode<Self>
pub fn evn() -> BoundCode<Self>
Evans Medical Limited (an affiliate of Medeva Pharmaceuticals, Inc.)
Sourcepub fn jpn() -> BoundCode<Self>
pub fn jpn() -> BoundCode<Self>
The Research Foundation for Microbial Diseases of Osaka University (BIKEN)
Sourcepub fn mip() -> BoundCode<Self>
pub fn mip() -> BoundCode<Self>
Bioport Corporation (formerly Michigan Biologic Products Institute)
North American Vaccine, Inc.
Sourcepub fn nov() -> BoundCode<Self>
pub fn nov() -> BoundCode<Self>
Novartis Pharmaceutical Corporation (includes Ciba-Geigy Limited and Sandoz Limited)
Sourcepub fn pmc() -> BoundCode<Self>
pub fn pmc() -> BoundCode<Self>
Aventis Pasteur Inc. (formerly Pasteur Merieux Connaught; includes Connaught Laboratories and Pasteur Merieux)
Sourcepub fn wal() -> BoundCode<Self>
pub fn wal() -> BoundCode<Self>
Wyeth-Ayerst (includes Wyeth-Lederle Vaccines and Pediatrics, Wyeth Laboratories, Lederle Laboratories, and Praxis Biologics)
pub fn null() -> BoundCode<Self>