pub struct OperationOutcome;Expand description
http://hl7.org/fhir/ValueSet/operation-outcome
Implementations
Sourceimpl OperationOutcome
impl OperationOutcome
Sourcepub fn delet_e_multipl_e_matches() -> BoundCode<Self>
pub fn delet_e_multipl_e_matches() -> BoundCode<Self>
Error: Multiple matches exist for the conditional delete
Sourcepub fn ms_g_aut_h_required() -> BoundCode<Self>
pub fn ms_g_aut_h_required() -> BoundCode<Self>
You must authenticate before you can use this service
Sourcepub fn ms_g_ba_d_format() -> BoundCode<Self>
pub fn ms_g_ba_d_format() -> BoundCode<Self>
Bad Syntax: “%s” must be a %s’
Sourcepub fn ms_g_ba_d_syntax() -> BoundCode<Self>
pub fn ms_g_ba_d_syntax() -> BoundCode<Self>
Bad Syntax in %s
Sourcepub fn ms_g_can_t_pars_e_content() -> BoundCode<Self>
pub fn ms_g_can_t_pars_e_content() -> BoundCode<Self>
Unable to parse feed (entry content type = “%s”)
Sourcepub fn ms_g_can_t_pars_e_root() -> BoundCode<Self>
pub fn ms_g_can_t_pars_e_root() -> BoundCode<Self>
Unable to parse feed (root element name = “%s”)
Sourcepub fn ms_g_created() -> BoundCode<Self>
pub fn ms_g_created() -> BoundCode<Self>
New resource created
Sourcepub fn ms_g_dat_e_format() -> BoundCode<Self>
pub fn ms_g_dat_e_format() -> BoundCode<Self>
The Date value %s is not in the correct format (Xml Date Format required)
Sourcepub fn ms_g_deleted() -> BoundCode<Self>
pub fn ms_g_deleted() -> BoundCode<Self>
This resource has been deleted
Sourcepub fn ms_g_delete_d_done() -> BoundCode<Self>
pub fn ms_g_delete_d_done() -> BoundCode<Self>
Resource deleted
Sourcepub fn ms_g_delete_d_id() -> BoundCode<Self>
pub fn ms_g_delete_d_id() -> BoundCode<Self>
The resource “%s” has been deleted
Sourcepub fn ms_g_duplicat_e_id() -> BoundCode<Self>
pub fn ms_g_duplicat_e_id() -> BoundCode<Self>
Duplicate Id %s for resource type %s
Sourcepub fn ms_g_erro_r_parsing() -> BoundCode<Self>
pub fn ms_g_erro_r_parsing() -> BoundCode<Self>
Error parsing resource Xml (%s)
Sourcepub fn ms_g_i_d_invalid() -> BoundCode<Self>
pub fn ms_g_i_d_invalid() -> BoundCode<Self>
Id “%s” has an invalid character “%s”
Sourcepub fn ms_g_i_d_to_o_long() -> BoundCode<Self>
pub fn ms_g_i_d_to_o_long() -> BoundCode<Self>
Id “%s” too long (length limit 36)
Sourcepub fn ms_g_invali_d_id() -> BoundCode<Self>
pub fn ms_g_invali_d_id() -> BoundCode<Self>
Id not accepted
Sourcepub fn ms_g_jso_n_object() -> BoundCode<Self>
pub fn ms_g_jso_n_object() -> BoundCode<Self>
Json Source for a resource should start with an object
Sourcepub fn ms_g_loca_l_fail() -> BoundCode<Self>
pub fn ms_g_loca_l_fail() -> BoundCode<Self>
Unable to resolve local reference to resource %s
Sourcepub fn ms_g_n_o_exist() -> BoundCode<Self>
pub fn ms_g_n_o_exist() -> BoundCode<Self>
Resource Id “%s” does not exist
Sourcepub fn ms_g_n_o_match() -> BoundCode<Self>
pub fn ms_g_n_o_match() -> BoundCode<Self>
No Resource found matching the query “%s”
Sourcepub fn ms_g_n_o_module() -> BoundCode<Self>
pub fn ms_g_n_o_module() -> BoundCode<Self>
No module could be found to handle the request “%s”
Sourcepub fn ms_g_n_o_summary() -> BoundCode<Self>
pub fn ms_g_n_o_summary() -> BoundCode<Self>
No Summary for this resource
Sourcepub fn ms_g_o_p_no_t_allowed() -> BoundCode<Self>
pub fn ms_g_o_p_no_t_allowed() -> BoundCode<Self>
Operation %s not allowed for resource %s (due to local configuration)
Sourcepub fn ms_g_para_m_chained() -> BoundCode<Self>
pub fn ms_g_para_m_chained() -> BoundCode<Self>
Unknown chained parameter name “%s”
Sourcepub fn ms_g_para_m_invalid() -> BoundCode<Self>
pub fn ms_g_para_m_invalid() -> BoundCode<Self>
Parameter “%s” content is invalid
Sourcepub fn ms_g_para_m_modifie_r_invalid() -> BoundCode<Self>
pub fn ms_g_para_m_modifie_r_invalid() -> BoundCode<Self>
Parameter “%s” modifier is invalid
Sourcepub fn ms_g_para_m_n_o_repeat() -> BoundCode<Self>
pub fn ms_g_para_m_n_o_repeat() -> BoundCode<Self>
Parameter “%s” is not allowed to repeat
Sourcepub fn ms_g_para_m_unknown() -> BoundCode<Self>
pub fn ms_g_para_m_unknown() -> BoundCode<Self>
Parameter “%s” not understood
Sourcepub fn ms_g_resourc_e_exampl_e_protected() -> BoundCode<Self>
pub fn ms_g_resourc_e_exampl_e_protected() -> BoundCode<Self>
Resources with identity “example” cannot be deleted (for testing/training purposes)
Sourcepub fn ms_g_resourc_e_i_d_fail() -> BoundCode<Self>
pub fn ms_g_resourc_e_i_d_fail() -> BoundCode<Self>
unable to allocate resource id
Sourcepub fn ms_g_resourc_e_i_d_mismatch() -> BoundCode<Self>
pub fn ms_g_resourc_e_i_d_mismatch() -> BoundCode<Self>
Resource Id Mismatch
Sourcepub fn ms_g_resourc_e_i_d_missing() -> BoundCode<Self>
pub fn ms_g_resourc_e_i_d_missing() -> BoundCode<Self>
Resource Id Missing
Sourcepub fn ms_g_resourc_e_no_t_allowed() -> BoundCode<Self>
pub fn ms_g_resourc_e_no_t_allowed() -> BoundCode<Self>
Not allowed to submit a resource for this operation
Sourcepub fn ms_g_resourc_e_required() -> BoundCode<Self>
pub fn ms_g_resourc_e_required() -> BoundCode<Self>
A resource is required
Sourcepub fn ms_g_resourc_e_typ_e_mismatch() -> BoundCode<Self>
pub fn ms_g_resourc_e_typ_e_mismatch() -> BoundCode<Self>
Resource Type Mismatch
Sourcepub fn ms_g_sor_t_unknown() -> BoundCode<Self>
pub fn ms_g_sor_t_unknown() -> BoundCode<Self>
Unknown sort parameter name “%s”
Sourcepub fn ms_g_transactio_n_duplicat_e_id() -> BoundCode<Self>
pub fn ms_g_transactio_n_duplicat_e_id() -> BoundCode<Self>
Duplicate Identifier in transaction: %s
Sourcepub fn ms_g_transactio_n_missin_g_id() -> BoundCode<Self>
pub fn ms_g_transactio_n_missin_g_id() -> BoundCode<Self>
Missing Identifier in transaction - an entry.id must be provided
Sourcepub fn ms_g_unhandle_d_nod_e_type() -> BoundCode<Self>
pub fn ms_g_unhandle_d_nod_e_type() -> BoundCode<Self>
Unhandled xml node type “%s”
Sourcepub fn ms_g_unknow_n_content() -> BoundCode<Self>
pub fn ms_g_unknow_n_content() -> BoundCode<Self>
Unknown Content (%s) at %s
Sourcepub fn ms_g_unknow_n_operation() -> BoundCode<Self>
pub fn ms_g_unknow_n_operation() -> BoundCode<Self>
unknown FHIR http operation
Sourcepub fn ms_g_unknow_n_type() -> BoundCode<Self>
pub fn ms_g_unknow_n_type() -> BoundCode<Self>
Resource Type “%s” not recognised
Sourcepub fn ms_g_updated() -> BoundCode<Self>
pub fn ms_g_updated() -> BoundCode<Self>
existing resource updated
Sourcepub fn ms_g_versio_n_aware() -> BoundCode<Self>
pub fn ms_g_versio_n_aware() -> BoundCode<Self>
Version aware updates are required for this resource
Sourcepub fn ms_g_versio_n_awar_e_conflict() -> BoundCode<Self>
pub fn ms_g_versio_n_awar_e_conflict() -> BoundCode<Self>
Update Conflict (server current version = “%s”, client version referenced = “%s”)
Sourcepub fn ms_g_versio_n_awar_e_url() -> BoundCode<Self>
pub fn ms_g_versio_n_awar_e_url() -> BoundCode<Self>
Version specific URL not recognised
Sourcepub fn ms_g_wron_g_ns() -> BoundCode<Self>
pub fn ms_g_wron_g_ns() -> BoundCode<Self>
This does not appear to be a FHIR element or resource (wrong namespace “%s”)
Sourcepub fn searc_h_multiple() -> BoundCode<Self>
pub fn searc_h_multiple() -> BoundCode<Self>
Error: Multiple matches exist for %s search parameters “%s”
Sourcepub fn searc_h_none() -> BoundCode<Self>
pub fn searc_h_none() -> BoundCode<Self>
Error: no processable search found for %s search parameters “%s”
Sourcepub fn updat_e_multipl_e_matches() -> BoundCode<Self>
pub fn updat_e_multipl_e_matches() -> BoundCode<Self>
Error: Multiple matches exist for the conditional update
pub fn null() -> BoundCode<Self>